---
jupyter: python3
---

```{python}
# This is an unfrozen cell. Works as usual.
print("I'm a regular cell so I run and print!")
```

```{python}
#| deletable: false
#| editable: false
#| run_control: {frozen: true}
# This is an frozen cell
print("I'm frozen so Im not executed :(")
```
